@@ -18,11 +18,13 @@ from functools import reduce
 from kmax.arch import Arch
 from kmax.common import get_kmax_constraints, unpickle_kmax_file
 from kmax.vcommon import getLogLevel, getLogger, run
+from kmax.kclause import tristate_pattern
+from kmax.kclause import tristate_config_gen
 
 builtin_rewrite_mapping = {
   "drivers/gpu/drm/amd/": "drivers/gpu/drm/amd/amdgpu/../",
   "drivers/gpu/drm/amd/amdgpu/": "drivers/gpu/drm/amd/amdgpu/",  # this path is more specific, so the parent directory will not be rewritten for amdgpu
-  "virt/kvm/": "arch/x86/kvm/../../../virt/kvm", # note that virt/kvm also applies to arm
+  "virt/kvm/": "arch/x86/kvm/../../../virt/kvm/", # note that virt/kvm also applies to arm
 }
 
 builtin_build_targets = {
@@ -340,7 +342,7 @@ class Klocalizer:
     config_file -- Path to a Kconfig config file.
     """
     assert os.path.isfile(config_file)
-    on_pattern = regex.compile("^(CONFIG_[A-Za-z0-9_]+)=[ym]")
+    on_pattern = regex.compile("^(CONFIG_[A-Za-z0-9_]+)=([ym])")
     off_pattern = regex.compile("^# (CONFIG_[A-Za-z0-9_]+) is not set")
     
     # todo: don't allow invisible defaults to be turned off (get them from kclause), reduces size of constraints
@@ -357,7 +359,11 @@ class Klocalizer:
         else:
           on = on_pattern.match(line)
           if on:
-            constraint = z3.Bool(on.group(1))
+            # TODO: use the boolean approximation of tristate if this is disabled by kclause.  currently the tristate modeling is kept on by klocalizer for kclause.  alternatively use biimplication between options, e.g., CONFIG_A <-> CONFIG_A=y, to support both kclause with and without tristate modeling simultaneously, though this will increase the number of clauses.
+            # var_name = on.group(1)
+            var_name = tristate_config_gen(on.group(1), on.group(2))
+            # sys.stderr.write(f"{var_name}\n")
+            constraint = z3.Bool(var_name)
             constraints.append(constraint)
       
       return constraints
@@ -453,6 +459,17 @@ class Klocalizer:
           # default value is from another variable, so it won't have a quoted value
           # TODO: support assigning default values from other config options
           pass
+    # collect any tristate settings
+    tristate_settings = {}
+    for entry in model:
+      str_entry = str(entry)
+      matches = tristate_pattern.match(str_entry)
+      if matches:
+        if model[entry]:
+          config_name = matches.groups()[0]
+          config_setting = matches.groups()[1]
+          tristate_settings[config_name] = config_setting
+    # print(tristate_settings)
     for entry in model: # the model has some problem, we can't get the entry
       str_entry = str(entry)
       matches = token_pattern.match(str_entry)
@@ -508,7 +525,11 @@ class Klocalizer:
             elif kconfig_types[str_entry] == "bool":
               write_to_content( "%s=y\n" % (str_entry) )
             elif kconfig_types[str_entry] == "tristate":
-              write_to_content( "%s=%s\n" % (str_entry, "y" if not set_tristate_m else "m") )
+              # check for a tristate variable to determine whether to set to y or m if it exists
+              if str_entry in tristate_settings.keys():
+                write_to_content( "%s=%s\n" % (str_entry, tristate_settings[str_entry]) )
+              else:
+                write_to_content( "%s=%s\n" % (str_entry, "y" if not set_tristate_m else "m") )
             elif kconfig_types[str_entry] == "string":
               if str_entry in approximate_config_original.keys():
                 write_to_content("%s\n" % (approximate_config_original[str_entry]))
@@ -533,7 +554,8 @@ class Klocalizer:
             else:
               assert(False)
           else:
-            if kconfig_types is None or str_entry in kconfig_types:
+            # if the solver set the option to false, then set it to 'n' in the output, but only for bool and tristate.  using the # CONFIG_A is not set pattern sets the option to false, which isn't valid for nonbools.
+            if kconfig_types is None or str_entry in kconfig_types and (kconfig_types[str_entry] == "tristate" or kconfig_types[str_entry] == "bool"):
               write_to_content( "# %s is not set\n" % (str_entry) )
             else:
               if str_entry not in Arch.ARCH_CONFIGS:
