@@ -396,7 +396,7 @@ class SuperC:
 
   def ensure_superc_config(self,
     srcfile: str, output_superc_configs_dir_path: str, linux_ksrc: str,
-    arch: Arch, cross_compiler, build_targets, compile_jobs, build_timeout,
+    arch: Arch, approximate_config, cross_compiler, build_targets, rewrite_build_target, compile_jobs, build_timeout,
     logger):
     """
     Ensure that SuperC configs exist for the input sourcefile.
@@ -431,7 +431,7 @@ class SuperC:
       # Localize a building configuration file.
       #
       output_config_file = logpath("kloc_localized_config")
-      ret_status, ret_arch, ret_exception = Klocalizer.localize_config([unit], output_config_file, linux_ksrc, [arch], logger)
+      ret_status, ret_arch, ret_exception = Klocalizer.localize_config([unit], output_config_file, linux_ksrc, [arch], {arch.name: approximate_config}, logger)
       # Write diagnostic info
       write_content_to_file(logpath("kloc_config_loc_status"), str(ret_status) + '\n')
       # no need to write ret_arch: there is already a single architecture
@@ -448,7 +448,7 @@ class SuperC:
       # Check if the unit compiles (also build them to prep for SuperC config creation)
       logger.debug("Attempting to build the unit.\n")
       ret = check_if_compiles([unit], output_config_file, arch.name, linux_ksrc,
-        build_targets, cross_compiler, compile_jobs, build_timeout, True, logger)
+      build_targets, rewrite_build_target, cross_compiler, compile_jobs, build_timeout, True, logger)
       is_unit_compiled, make_timed_out, make_ret, make_out, make_err, time_elapsed = ret
       write_content_to_file(logpath("build_unit_status"), str(is_unit_compiled) + '\n')
       write_content_to_file(logpath("build_unit_make_timed_out"), str(make_timed_out) + '\n')
@@ -456,7 +456,7 @@ class SuperC:
       write_content_to_file(logpath("build_unit_make_out"), str(make_out) + '\n')
       write_content_to_file(logpath("build_unit_make_err"), str(make_err) + '\n')
       write_content_to_file(logpath("build_unit_time_elapsed"), str(time_elapsed) + '\n')
-      if not is_unit_compiled:
+      if False in is_unit_compiled:
         logger.debug("Unit could not be compiled.\n")
         return False
       else:
@@ -646,7 +646,21 @@ class SyntaxAnalysis:
             if in_comment:
                 analyzed_tokens[line_num].append({token: "comment"})
             elif in_preprocessor:
-                analyzed_tokens[line_num].append({token: "preprocessor"})
+                # handle case where no space between directive and parenthesis
+                found_directive = False  # track if directive found
+                for directive in ['if', 'ifdef', 'ifndef', 'elif', 'else', 'endif']:
+                    if token.startswith(directive + '('):
+                        directive_token = directive
+                        remaining_token = token[len(directive):]  # capture remaining part by slicing at length of directive
+                        analyzed_tokens[line_num].append({directive_token: "preprocessor"})  # add directive
+                        if remaining_token:
+                            analyzed_tokens[line_num].append({remaining_token: "preprocessor"}) # add remaining token
+                            found_directive = True
+                        break
+
+                # if no directive found: just add token as whole
+                if not found_directive:
+                    analyzed_tokens[line_num].append({token: "preprocessor"})
             else:
                 analyzed_tokens[line_num].append({token: "c"})
 
